@@ -1,39 +1,43 @@
 package Firewall::Config::Content::Role;
 
 #------------------------------------------------------------------------------
-# 定义 Firewall::Config::Content::Role 角色属性 => 针对Class/package的调用
+# 加载扩展模块
 #------------------------------------------------------------------------------
 use Moose::Role;
+use namespace::autoclean;
 
 #------------------------------------------------------------------------------
-# 定义 Content 通用属性
+# 定义 Firewall::Config::Content::Role 通用属性
 #------------------------------------------------------------------------------
-has fwId => ( is => 'ro', isa => 'Int', required => 1, );
+has fwId => (is => 'ro', isa => 'Int', required => 1,);
 
-has fwName => ( is => 'ro', isa => 'Str', required => 1, );
+has fwName => (is => 'ro', isa => 'Str', required => 1,);
 
-has fwType => ( is => 'ro', isa => 'Str', required => 1, );
+has fwType => (is => 'ro', isa => 'Str', required => 1,);
 
-has confSign => ( is => 'ro', isa => 'Str', required => 1, );
+has confSign => (is => 'ro', isa => 'Str', required => 1,);
 
-has timestamp => ( is => 'ro', isa => 'Str', required => 1, );
+has timestamp => (is => 'ro', isa => 'Str', required => 1,);
 
-has lineParsedFlags => ( is => 'ro', isa => 'ArrayRef[Int]', builder => '_buildLineParsedFlags', );
+has lineParsedFlags => (is => 'ro', isa => 'ArrayRef[Int]', builder => '_buildLineParsedFlags',);
 
 #------------------------------------------------------------------------------
-# Content 子类必须实现的方法
+# 继承 Role 对象必须实现的属性
 #------------------------------------------------------------------------------
 requires 'config';
 requires 'confContent';
 requires 'cursor';
 
+#------------------------------------------------------------------------------
+# 继承 Role 对象必须实现的方法 | 解析配置的策略或动作
+#------------------------------------------------------------------------------
 requires 'goToHead';
 requires 'nextLine';
 requires 'prevLine';
-
 requires 'nextUnParsedLine';
 requires 'backtrack';
 requires 'ignore';
 requires 'getUnParsedLines';
+requires '_buildLineParsedFlags';
 
 1;
